//	PadControl.h - Combination of widgets to send OSC messages based around an
//				   XYPad.
//	----------------------------------------------------------------------------
//	This file is part of Mouse To OSC, a simple OSC-outputting program.
//	Copyright (c) 2006 Niall Moody.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//	----------------------------------------------------------------------------

#ifndef PADCONTROL_H_
#define PADCONTROL_H_

class XYPad;

//------------------------------------------------------------------------------
///	Combination of widgets to send OSC messages based around an XYPad.
class PadControl : public Component,
				   public ChangeBroadcaster,
				   public ChangeListener
{
  public:
	///	Constructor.
	PadControl();
	///	Destructor.
	~PadControl();

	///	Used to place the various widgets.
	void resized();

	///	Called when the user drags the XYPad control.
	void changeListenerCallback(void *objectThatHasChanged);

	///	Returns the OSC address for the x axis.
	String getXAddress() const {return addressXEditor->getText();};
	///	Returns the OSC address for the y axis.
	String getYAddress() const {return addressYEditor->getText();};
	///	Returns the y-axis maximum value.
	String getYMax() const {return yMax->getText();};
	///	Returns the y-axis minimum value.
	String getYMin() const {return yMin->getText();};
	///	Returns the x-axis maximum value.
	String getXMax() const {return xMax->getText();};
	///	Returns the y-axis minimum value.
	String getXMin() const {return xMin->getText();};
	///	Returns the value of the x axis.
	float getXVal() const;
	///	Returns the value of the y axis.
	float getYVal() const;
	///	Returns the x-axis MIDI CC.
	String getXCc() const {return xCc->getText();};
	///	Returns the y-axis MIDI CC.
	String getYCc() const {return yCc->getText();};

	///	Sets the OSC address for the x axis.
	void setXAddress(const String& val);
	///	Sets the OSC address for the y axis.
	void setYAddress(const String& val);
	///	Sets the y-axis maximum value.
	void setYMax(const String& val);
	///	Sets the y-axis minimum value.
	void setYMin(const String& val);
	///	Sets the x-axis maximum value.
	void setXMax(const String& val);
	///	Sets the x-axis minimum value.
	void setXMin(const String& val);
	///	Sets the value of the x axis.
	void setXVal(float val);
	///	Sets the value of the y axis.
	void setYVal(float val);
	///	Sets the x-axis MIDI CC.
	void setXCc(const String& val);
	///	Sets the y-axis MIDI CC.
	void setYCc(const String& val);

	///	Sets the X value normalised to 0->1.
	/*!
		Also generates change messages when called.
	 */
	void setXValNorm(float val);
	///	Sets the Y value normalised to 0->1.
	/*!
		Also generates change messages when called.
	 */
	void setYValNorm(float val);

    juce_UseDebuggingNewOperator
  private:
	///	Label for the address (x) editor.
	Label *addressXLabel;
	///	Address text (x) editor.
	TextEditor *addressXEditor;
	///	Label for the address (y) editor.
	Label *addressYLabel;
	///	Address text (y) editor.
	TextEditor *addressYEditor;
	///	XYPad control.
	XYPad *xyPad;

	///	Editor for the y-axis max value.
	TextEditor *yMax;
	///	Editor for the y-axis min value.
	TextEditor *yMin;
	///	Editor for the x-axis max value.
	TextEditor *xMax;
	///	Editor for the x-axis min value.
	TextEditor *xMin;
	///	Editor for the x-axis MIDI CC.
	TextEditor *xCc;
	///	Editor for the y-axis MIDI CC.
	TextEditor *yCc;
};

//------------------------------------------------------------------------------
///	Structure containing the values for the various PadControl widgets.
typedef struct
{
	String xAddress;
	String yAddress;
	String yMax;
	String yMin;
	String xMin;
	String xMax;
	float xVal;
	float yVal;
	String xCc;
	String yCc;
} PadControlValues;

#endif
