//	FileView.h - Abstract base class for file views.
//	----------------------------------------------------------------------------
//	This file is part of 'Phil', a very simple file manager/browser for the
//	JUCE library.
//	Copyright (C) 2005-2006  Niall Moody
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//	----------------------------------------------------------------------------

#ifndef FILEVIEW_H_
#define FILEVIEW_H_

//------------------------------------------------------------------------------
class Phil;

///	Abstract base class for file views.
/*!
	Phil embeds FileViews in a Viewport so they may be scrolled - as such,
	just follow the usual rules for creating Components for Viewports.
 */
class FileView : public Component
{
  public:
	///	Constructor.
	/*!
		\param parentComponent Pointer to the Phil Component this FileView
		resides in.  Subclasses should use this to communicate with Phil,
		via getPhil().
	 */
	FileView(Phil *parentComponent);
	///	Destructor.
	virtual ~FileView();

	///	Called by Phil to resize the view accordingly.
	/*!
		\param width The width of the space allocated to the enclosing
		Viewport.
		\param height The height of the space allocated to the enclosing
		Viewport.
		\param numChildren The number of children (files, directories) in
		the current directory.

		The idea is that certain kinds of file views may want to only scroll
		in one direction, and will therefore need to know how to place the
		files they're viewing, so that they don't disappear off the edge of
		the visible area.
	 */
	virtual void updateSize(int width, int height, long numChildren) {};
	///	Called by Phil when a new object has been selected.
	/*!
		\return A Rectangle containing the visual bounds of the object.

		The point of this is that the user will usually want to see the file
		they've just selected, so Phil will need to scroll the Viewport
		containing this FileView so that the object in question is on screen.
	 */
	virtual const Rectangle& getSelectedBounds() const = 0;

	///	Returns our Phil pointer.
	/*!
		Used by Phil::shorcutCallback().
	 */
	Phil *getPhil() const {return parent;};

	///	Returns an image displaying a folder, to represent a directory.
	/*!
		The image is 16x16.
	 */
	static const Image& getDefaultDirImage();
	///	Returns an image displaying a file.
	/*!
		The image is 16x16.
	 */
	static const Image& getDefaultFileImage();

	juce_UseDebuggingNewOperator
  private:
	Phil *parent;
};

#endif
