//	StandardPhilToolbar.h - Standard toolbar Component for Phil.
//	--------------------------------------------------------------------------
//	This file is part of 'Phil', a very simple file manager/browser for the
//	JUCE library.
//	Copyright (C) 2005-2006  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------

#ifndef STANDARDPHILTOOLBAR_H_
#define STANDARDPHILTOOLBAR_H_

#include <stack>

class Phil;

///	Standard toolbar Component for Phil.
/*!
	This just provides an 'up'/parent directory button and some limited
	history (back/forward) support.
 */
class StandardPhilToolbar : public Component,
							public ChangeListener,
							public ButtonListener
{
  public:
	///	Constructor.
	/*!
		\param parentComponent Pointer to the Phil Component this toolbar is
		part of.
	 */
	StandardPhilToolbar(Phil *parentComponent);
	///	Destructor.
	~StandardPhilToolbar();

	///	To place the buttons correctly.
	void resized();
	///	So we get informed when the Phil Component has moved to another directory etc.
	void changeListenerCallback(void *objectThatHasChanged);
	///	So we get informed when the user clicks a button.
	void buttonClicked(Button *button);

	juce_UseDebuggingNewOperator
  private:
	///	Back button.
	DrawableButton *backButton;
	///	Forward button.
	DrawableButton *forwardButton;
	///	Up button.
	DrawableButton *upButton;
	///	Home button.
	DrawableButton *homeButton;

	///	Pointer to the 'parent' Phil Component.
	Phil *parent;

	///	The directory the user is currently viewing.
	String currentDirectory;
	///	The 'back' history.
	/*!
		Holds all the paths the user has previously viewed.
	 */
	std::stack<String *> backHistory;
	///	The 'forward' history.
	/*!
		Holds all the paths the user has previously viewed.
	 */
	std::stack<String *> forwardHistory;
};

#endif
